@@ -1,22 +1,10 @@
 package Email::Sender::Failure::Multi;
-use Mouse;
+our $VERSION = '0.091560_001';
+
+use Moose;
 extends 'Email::Sender::Failure';
+# ABSTRACT: an aggregate of multiple failures
 
-our $VERSION = '0.000';
-
-=head1 DESCRIPTION
-
-A multiple failure report is raised when more than one failure is encountered
-when sending a single message, or when mixed states were encountered.
-
-=head1 METHODS
-
-=head2 failures
-
-This method returns a list (or arrayref, in scalar context) of other
-Email::Sender::Failure objects represented by this multi.
-
-=cut
 
 has failures => (
   is  => 'ro',
@@ -30,12 +18,6 @@ sub recipients {
   return wantarray ? @rcpts : \@rcpts;
 }
 
-=head2 isa
-
-A multiple failure will report that it is a Permanent or Temporary if all of
-its contained failures are failures of that type.
-
-=cut
 
 sub isa {
   my ($self, $class) = @_;
@@ -53,5 +35,51 @@ sub isa {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::Sender::Failure::Multi - an aggregate of multiple failures
+
+=head1 VERSION
+
+version 0.091560_001
+
+=head1 DESCRIPTION
+
+A multiple failure report is raised when more than one failure is encountered
+when sending a single message, or when mixed states were encountered.
+
+=head1 ATTRIBUTES
+
+=head2 failures
+
+This method returns a list (or arrayref, in scalar context) of other
+Email::Sender::Failure objects represented by this multi.
+
+=head1 METHODS
+
+=head2 isa
+
+A multiple failure will report that it is a Permanent or Temporary if all of
+its contained failures are failures of that type.
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut 
+
+
