@@ -1,14 +1,9 @@
 package Email::Sender::Transport::Failable;
-use Mouse;
+our $VERSION = '0.091560_001';
+
+use Moose;
 extends 'Email::Sender::Transport::Wrapper';
-
-our $VERSION = '0.000';
-
-=head1 NAME
-
-Email::Sender::Transport::Failable - a wrapper to makes things fail predictably
-
-=cut
+# ABSTRACT: a wrapper to makes things fail predictably
 
 has 'failure_conditions' => (
   is  => 'ro',
@@ -36,5 +31,32 @@ around send_email => sub {
 };
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::Sender::Transport::Failable - a wrapper to makes things fail predictably
+
+=head1 VERSION
+
+version 0.091560_001
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut 
+
+
