@@ -1,14 +1,9 @@
 package Email::Sender::Transport::Print;
-use Mouse;
-extends 'Email::Sender::Transport';
+our $VERSION = '0.091560_001';
 
-our $VERSION = '0.000';
-
-=head1 NAME
-
-Email::Sender::Transport::Print - print email to a filehandle (like stdout)
-
-=cut
+use Moose;
+with 'Email::Sender::Transport';
+# ABSTRACT: print email to a filehandle (like stdout)
 
 use IO::Handle;
 
@@ -36,5 +31,32 @@ sub send_email {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::Sender::Transport::Print - print email to a filehandle (like stdout)
+
+=head1 VERSION
+
+version 0.091560_001
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut 
+
+
