@@ -1,25 +1,10 @@
 package Email::Sender::Transport::Sendmail;
-use Mouse;
-extends 'Email::Sender::Transport';
+our $VERSION = '0.091560_001';
 
-our $VERSION = '0.000';
+use Moose;
+with 'Email::Sender::Transport';
+# ABSTRACT: send mail via sendmail(1)
 
-=head1 NAME
-
-Email::Sender::Transport::Sendmail - send mail via sendmail(1)
-
-=head2 DESCRIPTION
-
-This transport sends mail by piping it to the F<sendmail> command.  If the
-location of the F<sendmail> command is not provided in the constructor (see
-below) then the library will look for an executable file called F<sendmail> in
-the path.
-
-To specify the location of sendmail:
-
-  my $sender = Email::Sender::Transport::Sendmail->new({ sendmail => $path });
-
-=cut
 
 use File::Spec ();
 
@@ -29,7 +14,7 @@ has 'sendmail' => (
   required => 1,
   lazy     => 1,
   default  => sub {
-    # This should not have to be lazy, but Mouse has a bug(?) that prevents the
+    # This should not have to be lazy, but Moose has a bug(?) that prevents the
     # instance or partial-instance from being passed in to the default sub.
     # Laziness doesn't hurt much, though, because (ugh) of the BUILD below.
     # -- rjbs, 2008-12-04
@@ -45,21 +30,33 @@ sub _find_sendmail {
 
   for my $dir (File::Spec->path) {
     my $sendmail = File::Spec->catfile($dir, $program_name);
-    return $sendmail if -x $sendmail;
+    return $sendmail if ($^O eq 'MSWin32') ? -f $sendmail : -x $sendmail;
   }
 
   Carp::confess("couldn't find a sendmail executable");
 }
 
+sub _sendmail_pipe {
+  my ($self, $envelope) = @_;
+
+  my $prog = $self->sendmail;
+
+  my ($first, @args) = $^O eq 'MSWin32'
+           ? qq(| "$prog" -f $envelope->{from} @{$envelope->{to}})
+           : (q{|-}, $prog, '-f', $envelope->{from}, @{$envelope->{to}});
+
+  no warnings 'exec'; ## no critic
+  my $pipe;
+  Email::Sender::Failure->throw("couldn't open pipe to sendmail ($prog): $!")
+    unless open($pipe, $first, @args);
+
+  return $pipe;
+}
+
 sub send_email {
   my ($self, $email, $envelope) = @_;
 
-  my $sendmail = $self->sendmail;
-
-  # This isn't a problem; we die if it fails, anyway. -- rjbs, 2007-07-17
-  no warnings 'exec'; ## no critic
-  open my $pipe, q{|-}, ($sendmail, '-f', $envelope->{from}, @{$envelope->{to}})
-    or Email::Sender::Failure->throw("couldn't open pipe to sendmail: $!");
+  my $pipe = $self->_sendmail_pipe($envelope);
 
   print $pipe $email->as_string
     or Email::Sender::Failure->throw("couldn't send message to sendmail: $!");
@@ -71,5 +68,43 @@ sub send_email {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::Sender::Transport::Sendmail - send mail via sendmail(1)
+
+=head1 VERSION
+
+version 0.091560_001
+
+=head2 DESCRIPTION
+
+This transport sends mail by piping it to the F<sendmail> command.  If the
+location of the F<sendmail> command is not provided in the constructor (see
+below) then the library will look for an executable file called F<sendmail> in
+the path.
+
+To specify the location of sendmail:
+
+  my $sender = Email::Sender::Transport::Sendmail->new({ sendmail => $path });
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut 
+
+
