@@ -1,14 +1,9 @@
 package Email::Sender::Transport::Test;
-use Mouse;
-extends 'Email::Sender::Transport';
+our $VERSION = '0.091560_001';
 
-our $VERSION = '0.000';
-
-=head1 NAME
-
-Email::Sender::Transport::Test - delivery mail in memory for testing
-
-=cut
+use Moose;
+with 'Email::Sender::Transport';
+# ABSTRACT: deliver mail in memory for testing
 
 use Email::Sender::Failure::Multi;
 use Email::Sender::Success::Partial;
@@ -83,5 +78,32 @@ sub send_email {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::Sender::Transport::Test - deliver mail in memory for testing
+
+=head1 VERSION
+
+version 0.091560_001
+
+=head1 AUTHOR
+
+  Ricardo Signes <rjbs@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Ricardo Signes.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=cut 
+
+
