@@ -1,22 +1,10 @@
 package Email::Sender::Transport::Wrapper;
-use Mouse;
-extends 'Email::Sender::Transport';
+our $VERSION = '0.091560_001';
 
-our $VERSION = '0.000';
+use Moose;
+with 'Email::Sender::Transport';
+# ABSTRACT: a mailer to wrap a mailer for mailing mail
 
-use Carp;
-
-=head1 NAME
-
-Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
-
-=head1 DESCRIPTION
-
-Email::Sender::Transport::Wrapper wraps a transport, provided as the
-C<transport> argument to the constructor.  It is provided as a simple way to
-use method modifiers to create wrapping classes.
-
-=cut
 
 has transport => (
   is  => 'ro',
@@ -30,26 +18,39 @@ sub send_email {
   $self->transport->send_email(@_);
 }
 
+__PACKAGE__->meta->make_immutable;
+no Moose;
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::Sender::Transport::Wrapper - a mailer to wrap a mailer for mailing mail
+
+=head1 VERSION
+
+version 0.091560_001
+
+=head1 DESCRIPTION
+
+Email::Sender::Transport::Wrapper wraps a transport, provided as the
+C<transport> argument to the constructor.  It is provided as a simple way to
+use method modifiers to create wrapping classes.
+
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+  Ricardo Signes <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to
-C<bug-email-send-mailer@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2009 by Ricardo Signes.
 
-=head1 COPYRIGHT
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
 
-Copyright 2006-2008, Ricardo SIGNES, all rights reserved.
+=cut 
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
 
-=cut
-
-__PACKAGE__->meta->make_immutable;
-no Mouse;
-1;
