@@ -1,5 +1,7 @@
 package Test::Email::SMTPRig;
-use Mouse;
+our $VERSION = '0.091560_001';
+
+use Moose;
 
 has 'smtp_host' => (is => 'ro', required => 1);
 has 'smtp_ssl'  => (is => 'ro', default  => 0);
@@ -66,5 +68,5 @@ has 'plan' => (
 );
 
 __PACKAGE__->meta->make_immutable;
-no Mouse;
+no Moose;
 1;
