@@ -1,6 +1,8 @@
 use strict;
 use warnings;
 package Test::Email::Sender::Util;
+our $VERSION = '0.091560_001';
+
 use Exporter;
 BEGIN { our @ISA = qw(Exporter) }
 
@@ -41,6 +43,7 @@ sub perform_stock_mockery {
   });
 
   $mock_smtp->mock(reset => sub { $_[0]->succ });
+  $mock_smtp->mock(quit  => sub { $_[0]->succ });
 
   $mock_smtp->mock(auth => sub {
     my ($self, $user, $pass) = @_;
